# aiorequestful

[![PyPI Version](https://img.shields.io/pypi/v/aiorequestful?logo=pypi&label=Latest%20Version)](https://pypi.org/project/aiorequestful)
[![Python Version](https://img.shields.io/pypi/pyversions/aiorequestful.svg?logo=python&label=Supported%20Python%20Versions)](https://pypi.org/project/aiorequestful/)
[![Documentation](https://img.shields.io/badge/Documentation-red.svg)](https://geo-martino.github.io/aiorequestful/)
</br>
[![PyPI Downloads](https://img.shields.io/pypi/dm/aiorequestful?label=Downloads)](https://pypi.org/project/aiorequestful/)
[![Code Size](https://img.shields.io/github/languages/code-size/geo-martino/aiorequestful?label=Code%20Size)](https://github.com/geo-martino/aiorequestful)
[![Contributors](https://img.shields.io/github/contributors/geo-martino/aiorequestful?logo=github&label=Contributors)](https://github.com/geo-martino/aiorequestful/graphs/contributors)
[![License](https://img.shields.io/github/license/geo-martino/aiorequestful?label=License)](https://github.com/geo-martino/aiorequestful/blob/master/LICENSE)
</br>
[![GitHub - Validate](https://github.com/geo-martino/aiorequestful/actions/workflows/validate.yml/badge.svg?branch=master)](https://github.com/geo-martino/aiorequestful/actions/workflows/validate.yml)
[![GitHub - Deployment](https://github.com/geo-martino/aiorequestful/actions/workflows/deploy.yml/badge.svg?event=release)](https://github.com/geo-martino/aiorequestful/actions/workflows/deploy.yml)
[![GitHub - Documentation](https://github.com/geo-martino/aiorequestful/actions/workflows/docs_publish.yml/badge.svg)](https://github.com/geo-martino/aiorequestful/actions/workflows/docs_publish.yml)

### An Asynchronous HTTP and RESTful API requests framework for asyncio and Python

## Contents
* [Getting Started](#quick-guides)
* [Currently Supported](#currently-supported)
* [Release History](#release-history)
* [Contributing](#contributing)
* [Motivation & Aims](#aims)
* [Author Notes](#notes)

> **NOTE:**  
> This readme provides a brief overview of the program. 
> [Read the docs](https://geo-martino.github.io/aiorequestful/) for full reference documentation.


## Installation
Install through pip using one of the following commands:

```bash
pip install aiorequestful
```
```bash
python -m pip install aiorequestful
```

There are optional dependencies that you may install for optional functionality. 
For the current list of optional dependency groups, [read the docs](https://geo-martino.github.io/aiorequestful/howto.install.html)


## Getting Started

These quick guides will help you get set up and going with aiorequestful in just a few minutes.
For more detailed guides, check out the [documentation](https://geo-martino.github.io/aiorequestful/).

***Coming soon...***


## Currently Supported

- **Cache Backends**: `SQLiteCache`
- **Basic Authorisation**: `BasicAuthoriser`
- **OAuth2 Flows**: `AuthorisationCodeFlow` `AuthorisationCodePKCEFlow` `ClientCredentialsFlow`


## Release History

For change and release history, 
check out the [documentation](https://geo-martino.github.io/aiorequestful/release-history.html).


## Contributing

For info on how to contribute to aiorequestful, 
check out the [documentation](https://geo-martino.github.io/aiorequestful/contributing.html).


<a id="aims"></a>
## Motivations & Aims

***Coming soon...***


<a id="notes"></a>
## Author notes, contributions, and reporting issues

***Coming soon...***